
#ifndef _C10_kl473_
#define _C10_kl473_

#ifdef __cplusplus
extern "C" {
#endif
RTOSHF (EIF_REFERENCE, 12458)


extern EIF_REFERENCE F1372_12458(EIF_REFERENCE);
extern void F1372_12459(EIF_REFERENCE);
extern void EIF_Minit473(void);
extern void F691_5666(EIF_REFERENCE);

#ifdef __cplusplus
}
#endif

#endif
